aboutsummaryrefslogtreecommitdiff
path: root/include/io.h
diff options
context:
space:
mode:
authorjohannst <johannes.stoelp@gmail.com>2020-11-29 16:17:28 +0100
committerjohannst <johannes.stoelp@gmail.com>2020-11-29 16:17:28 +0100
commit6b6c7ca4f4cce33595b4187f23d4003aecef47f6 (patch)
tree2b0f790fd3577c63ffaa7a19ac14bdff8ff22610 /include/io.h
parentd103cc99e36e0579c3891f6f8e9666bf9fa0f44d (diff)
downloaddynld-6b6c7ca4f4cce33595b4187f23d4003aecef47f6.tar.gz
dynld-6b6c7ca4f4cce33595b4187f23d4003aecef47f6.zip
rename fmt & print functions
Diffstat (limited to 'include/io.h')
-rw-r--r--include/io.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/io.h b/include/io.h
index 4b3ea4b..d9a1ae1 100644
--- a/include/io.h
+++ b/include/io.h
@@ -7,7 +7,7 @@
#include <asm/unistd.h>
// `dynld_printf` uses fixed-size buffer on the stack for formating the message
// (since we don't impl buffered I/O).
//
// Size can be re-configured by defining `MAX_PRINTF_LEN` before including
@@ -16,24 +16,24 @@
// NOTE: This allows to specify an arbitrarily large buffer on the stack, but
// for the purpose of this study that's fine, we are cautious.
#if !defined(MAX_PRINTF_LEN)
-# define MAX_PRINTF_LEN 64
+# define MAX_PRINTF_LEN 128
#endif
#define FD_STDOUT 1
#define FD_STDERR 2
-int dynld_printf(const char* fmt, ...) {
+static int pfmt(const char* fmt, ...) {
char buf[MAX_PRINTF_LEN];
va_list ap;
va_start(ap, fmt);
- int ret = dynld_vsnprintf(buf, sizeof(buf), fmt, ap);
+ int ret = vfmt(buf, sizeof(buf), fmt, ap);
va_end(ap);
if (ret > MAX_PRINTF_LEN - 1) {
syscall3(__NR_write, FD_STDERR, buf, MAX_PRINTF_LEN - 1);
- static const char warn[] = "\ndynld_printf: Message truncated, max length can be configured by defining MAX_PRINTF_LEN\n";
+ static const char warn[] = "\npfmt: Message truncated, max length can be configured by defining MAX_PRINTF_LEN\n";
syscall3(__NR_write, FD_STDOUT, warn, sizeof(warn));
return MAX_PRINTF_LEN - 1;
}
@@ -7,7 +7,7 @@
#include <asm/unistd.h>
-// `dynld_printf` uses fixed-size buffer on the stack for formating the message
+// `pfmt` uses fixed-size buffer on the stack for formating the message
// (since we don't impl buffered I/O).
//